==> ibus-qt_1.3.0-1maemo2.tar.gz: ibus-qt-1.3.0/cmake_install.cmake <==
# Install script for directory: /home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo

# Set the install prefix
IF(NOT DEFINED CMAKE_INSTALL_PREFIX)
  SET(CMAKE_INSTALL_PREFIX "/opt/maemocjk2/usr")
ENDIF(NOT DEFINED CMAKE_INSTALL_PREFIX)
STRING(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
IF(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)
  IF(BUILD_TYPE)
    STRING(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  ELSE(BUILD_TYPE)
    SET(CMAKE_INSTALL_CONFIG_NAME "")
  ENDIF(BUILD_TYPE)
  MESSAGE(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
ENDIF(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)

# Set the component getting installed.
IF(NOT CMAKE_INSTALL_COMPONENT)
  IF(COMPONENT)
    MESSAGE(STATUS "Install component: \"${COMPONENT}\"")
    SET(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  ELSE(COMPONENT)
    SET(CMAKE_INSTALL_COMPONENT)
  ENDIF(COMPONENT)
ENDIF(NOT CMAKE_INSTALL_COMPONENT)

# Install shared libraries without execute permission?
IF(NOT DEFINED CMAKE_INSTALL_SO_NO_EXE)
  SET(CMAKE_INSTALL_SO_NO_EXE "1")
ENDIF(NOT DEFINED CMAKE_INSTALL_SO_NO_EXE)

IF(NOT CMAKE_INSTALL_COMPONENT OR "${CMAKE_INSTALL_COMPONENT}" STREQUAL "Unspecified")
  FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/doc/ibus-qt-1.3.0" TYPE FILE FILES
    "/home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo/AUTHORS"
    "/home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo/README"
    "/home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo/INSTALL"
    )
ENDIF(NOT CMAKE_INSTALL_COMPONENT OR "${CMAKE_INSTALL_COMPONENT}" STREQUAL "Unspecified")

IF(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for each subdirectory.
  INCLUDE("/home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo/src/cmake_install.cmake")
  INCLUDE("/home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo/qtim/cmake_install.cmake")
  INCLUDE("/home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo/test/cmake_install.cmake")
  INCLUDE("/home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo/docs/cmake_install.cmake")

ENDIF(NOT CMAKE_INSTALL_LOCAL_ONLY)

IF(CMAKE_INSTALL_COMPONENT)
  SET(CMAKE_INSTALL_MANIFEST "install_manifest_${CMAKE_INSTALL_COMPONENT}.txt")
ELSE(CMAKE_INSTALL_COMPONENT)
  SET(CMAKE_INSTALL_MANIFEST "install_manifest.txt")
ENDIF(CMAKE_INSTALL_COMPONENT)

FILE(WRITE "/home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo/${CMAKE_INSTALL_MANIFEST}" "")
FOREACH(file ${CMAKE_INSTALL_MANIFEST_FILES})
  FILE(APPEND "/home/takahiro/devel/kenya888s-maemocjk/kenya888s-maemocjk/ibus-qt-1.3.0-maemo/${CMAKE_INSTALL_MANIFEST}" "${file}\n")
ENDFOREACH(file)

==> ibus-qt_1.3.1-1maemo2.tar.gz: ibus-qt-1.3.1/cmake_install.cmake <==
# Install script for directory: /home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo

# Set the install prefix
IF(NOT DEFINED CMAKE_INSTALL_PREFIX)
  SET(CMAKE_INSTALL_PREFIX "/usr")
ENDIF(NOT DEFINED CMAKE_INSTALL_PREFIX)
STRING(REGEX REPLACE "/$" "" CMAKE_INSTALL_PREFIX "${CMAKE_INSTALL_PREFIX}")

# Set the install configuration name.
IF(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)
  IF(BUILD_TYPE)
    STRING(REGEX REPLACE "^[^A-Za-z0-9_]+" ""
           CMAKE_INSTALL_CONFIG_NAME "${BUILD_TYPE}")
  ELSE(BUILD_TYPE)
    SET(CMAKE_INSTALL_CONFIG_NAME "")
  ENDIF(BUILD_TYPE)
  MESSAGE(STATUS "Install configuration: \"${CMAKE_INSTALL_CONFIG_NAME}\"")
ENDIF(NOT DEFINED CMAKE_INSTALL_CONFIG_NAME)

# Set the component getting installed.
IF(NOT CMAKE_INSTALL_COMPONENT)
  IF(COMPONENT)
    MESSAGE(STATUS "Install component: \"${COMPONENT}\"")
    SET(CMAKE_INSTALL_COMPONENT "${COMPONENT}")
  ELSE(COMPONENT)
    SET(CMAKE_INSTALL_COMPONENT)
  ENDIF(COMPONENT)
ENDIF(NOT CMAKE_INSTALL_COMPONENT)

# Install shared libraries without execute permission?
IF(NOT DEFINED CMAKE_INSTALL_SO_NO_EXE)
  SET(CMAKE_INSTALL_SO_NO_EXE "1")
ENDIF(NOT DEFINED CMAKE_INSTALL_SO_NO_EXE)

IF(NOT CMAKE_INSTALL_COMPONENT OR "${CMAKE_INSTALL_COMPONENT}" STREQUAL "Unspecified")
  FILE(INSTALL DESTINATION "${CMAKE_INSTALL_PREFIX}/share/doc/ibus-qt-1.3.1" TYPE FILE FILES
    "/home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo/AUTHORS"
    "/home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo/README"
    "/home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo/INSTALL"
    )
ENDIF(NOT CMAKE_INSTALL_COMPONENT OR "${CMAKE_INSTALL_COMPONENT}" STREQUAL "Unspecified")

IF(NOT CMAKE_INSTALL_LOCAL_ONLY)
  # Include the install script for each subdirectory.
  INCLUDE("/home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo/src/cmake_install.cmake")
  INCLUDE("/home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo/qtim/cmake_install.cmake")
  INCLUDE("/home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo/test/cmake_install.cmake")
  INCLUDE("/home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo/docs/cmake_install.cmake")

ENDIF(NOT CMAKE_INSTALL_LOCAL_ONLY)

IF(CMAKE_INSTALL_COMPONENT)
  SET(CMAKE_INSTALL_MANIFEST "install_manifest_${CMAKE_INSTALL_COMPONENT}.txt")
ELSE(CMAKE_INSTALL_COMPONENT)
  SET(CMAKE_INSTALL_MANIFEST "install_manifest.txt")
ENDIF(CMAKE_INSTALL_COMPONENT)

FILE(WRITE "/home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo/${CMAKE_INSTALL_MANIFEST}" "")
FOREACH(file ${CMAKE_INSTALL_MANIFEST_FILES})
  FILE(APPEND "/home/kenya888/devel/kenya888s-maemocjk/ibus-qt-1.3.1-maemo/${CMAKE_INSTALL_MANIFEST}" "${file}\n")
ENDFOREACH(file)
